Skip to contents

Converts line sizes measured as points (as given by most programs such as Adobe Illustrator etc.) to ggplot font sizes

Usage

LS(x)

Arguments

x

numeric vector giving the lines sizes in points

Value

Returns a numeric vector of length x of ggplot line sizes