Skip to contents

List of core data types used in the processBioticFile function

Usage

coreDataList(type)

Arguments

type

character string specifying the data type. Alternatives: "mission", "fishstation", "individual", "catchsample", or "agedetermination".

Value

Returns a character vector of core data types for a given data type.

Author

Mikko Vihtakari (Institute of Marine Research)