Use the prepareCruiseSeriesList function to update the list. Need to be updated every time data from the database are downloaded.
Institute of Marine Research (https://imr.no)
Use the prepareCruiseSeriesList function to update the list. Need to be updated every time data from the database are downloaded.
Institute of Marine Research (https://imr.no)