Skip to contents

Uses fuzzy matching (agrep) to guess (column) names from a list of allowed character strings.

Usage

guess_colname(cols, df, candidates = coln_search_words)

Arguments

cols

Character vector of approximate column names to be guessed

df

data frame containing column names

candidates

a switch argument or a character vector giving the candidates to be used in matching. The coln_search_words function is used by default.

Author

Mikko Vihtakari, Conrad Helgeland