List of core data columns by data type in NMD Biotic data
Source:R/processBiotic_functions.R
coreDataList.RdList of core data types used in the processBioticFile function
R/processBiotic_functions.R
coreDataList.RdList of core data types used in the processBioticFile function