Skip to contents

The function downloads sales note/landings ("sluttseddel") data from IMR database. Requires access to the intranet.

Usage

downloadLandings(species, years = NULL, returned_data = "both")

Arguments

species

any species identification name in FDIRcodes$speciesCodes as character. Only one species at the time allowed.

years

an integer vector of years to download. If NULL (default), all years are downloaded. Please note that this option can take very long time and lead to huge datasets.

returned_data

character argument specifying what type of data should be returned. Use "sales notes" to return the original sales note data from the server, "summary" to only return summarized catches, or "both" to return both sales notes and summarized catches in a list.

See also

Other Landings functions: readSluttseddelXLS()

Author

Mikko Vihtakari

Examples

if (FALSE) { # \dontrun{
downloadLandings("brugde") # Basking shark, all years
downloadLandings("kveite", years = 2000:2001) # halibut, 2000-01
} # }