Uses fuzzy matching (agrep) to guess (column) names from a list of allowed character strings.
Arguments
- cols
Character vector of approximate column names to be guessed
- df
data frame containing column names
- candidates
a switch argument or a character vector giving the candidates to be used in matching. The
coln_search_wordsfunction is used by default.